#ifndef DEFINES_H
 #define DEFINES_H
 #include <defines.h>
#endif

/* mcrypt.c */
int encrypt_ucrypt(char *fromfile,char *tofile, char *key);
void usage(char *);
int encrypt_general(int algorithm, char *fromfile,char *tofile,char *key);
int decrypt_general(int algorithm, char *fromfile,char *tofile,char *key);

int check_algo(char *chain); /* input is the algorithms name... output the
                              * algorithm's number
                              */
int check_mode(char *chain);

/* Solaris des(3) */
int encrypt_desc(char *fromfile, char *tofile, char *key);
int decrypt_desc(char *fromfile, char *tofile, char *key);
